@@ -1270,6 +1270,11 @@ ACTUALIZE_RESULT_SCHEMA = '''{
                         "minItems": 2,
                         "type": "array"
                     },
+                    "comment": {
+                        "maxLength": 10000,
+                        "minLength": 0,
+                        "type": "string"
+                    },
                     "finish_location_key": {
                         "maxLength": 1024,
                         "minLength": 1,
@@ -1435,11 +1440,21 @@ ACTUALIZE_RESULT_SCHEMA = '''{
                                 "minItems": 0,
                                 "type": "array"
                             },
+                            "comment": {
+                                "maxLength": 10000,
+                                "minLength": 0,
+                                "type": "string"
+                            },
                             "demands": {
                                 "items": {
                                     "additionalProperties": false,
                                     "nullable": false,
                                     "properties": {
+                                        "comment": {
+                                            "maxLength": 10000,
+                                            "minLength": 0,
+                                            "type": "string"
+                                        },
                                         "demand_type": {
                                             "enum": [
                                                 "PICKUP",
