@@ -55,6 +55,11 @@ PLAN_TASK_SCHEMA = '''{
                 "additionalProperties": false,
                 "nullable": false,
                 "properties": {
+                    "comment": {
+                        "maxLength": 10000,
+                        "minLength": 0,
+                        "type": "string"
+                    },
                     "key": {
                         "maxLength": 1024,
                         "minLength": 1,
@@ -279,11 +284,21 @@ PLAN_TASK_SCHEMA = '''{
                         "minItems": 0,
                         "type": "array"
                     },
+                    "comment": {
+                        "maxLength": 10000,
+                        "minLength": 0,
+                        "type": "string"
+                    },
                     "demands": {
                         "items": {
                             "additionalProperties": false,
                             "nullable": false,
                             "properties": {
+                                "comment": {
+                                    "maxLength": 10000,
+                                    "minLength": 0,
+                                    "type": "string"
+                                },
                                 "demand_type": {
                                     "enum": [
                                         "PICKUP",
@@ -473,6 +488,11 @@ PLAN_TASK_SCHEMA = '''{
                 "additionalProperties": false,
                 "nullable": false,
                 "properties": {
+                    "comment": {
+                        "maxLength": 10000,
+                        "minLength": 0,
+                        "type": "string"
+                    },
                     "key": {
                         "maxLength": 1024,
                         "minLength": 1,
@@ -929,6 +949,11 @@ PLAN_TASK_SCHEMA = '''{
                         ],
                         "type": "object"
                     },
+                    "comment": {
+                        "maxLength": 10000,
+                        "minLength": 0,
+                        "type": "string"
+                    },
                     "finish_location_key": {
                         "maxLength": 1024,
                         "minLength": 1,
@@ -1178,6 +1203,11 @@ PLAN_TASK_SCHEMA = '''{
                         "minItems": 1,
                         "type": "array"
                     },
+                    "comment": {
+                        "maxLength": 10000,
+                        "minLength": 0,
+                        "type": "string"
+                    },
                     "key": {
                         "maxLength": 1024,
                         "minLength": 1,
@@ -1362,6 +1392,11 @@ PLAN_TASK_SCHEMA = '''{
                         "minItems": 2,
                         "type": "array"
                     },
+                    "comment": {
+                        "maxLength": 10000,
+                        "minLength": 0,
+                        "type": "string"
+                    },
                     "finish_location_key": {
                         "maxLength": 1024,
                         "minLength": 1,
