@@ -10,6 +10,11 @@ PREDICT_TASK_SCHEMA = '''{
                 "additionalProperties": false,
                 "nullable": false,
                 "properties": {
+                    "comment": {
+                        "maxLength": 10000,
+                        "minLength": 0,
+                        "type": "string"
+                    },
                     "key": {
                         "maxLength": 1024,
                         "minLength": 1,
@@ -233,11 +238,21 @@ PREDICT_TASK_SCHEMA = '''{
                     "minItems": 0,
                     "type": "array"
                 },
+                "comment": {
+                    "maxLength": 10000,
+                    "minLength": 0,
+                    "type": "string"
+                },
                 "demands": {
                     "items": {
                         "additionalProperties": false,
                         "nullable": false,
                         "properties": {
+                            "comment": {
+                                "maxLength": 10000,
+                                "minLength": 0,
+                                "type": "string"
+                            },
                             "demand_type": {
                                 "enum": [
                                     "PICKUP",
